/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Calendar **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "{0}, the {1}. of {2}"
: "{0}, ที่ {1} จาก {2}"

, "Recurrances"
: "ความซ้ำซ้อน"

, "No recurring rule defined"
: "ไม่ได้มีกฎเกี่ยวกับการซ้ำซ้อนระบุไว้"

, "Details"
: "รายละเอียด"

, "None"
: "ไม่มีเลย"

, "Daily"
: "ทุกวัน"

, "Weekly"
: "ทุกสัปดาห์"

, "Monthly"
: "ทุกเดือน"

, "Yearly"
: "ทุกปี"

, "Exceptions of reccuring events can't have recurrences themselves."
: "ข้อยกเว้นเกี่ยวกับเหตุการณ์ที่ซ้ำซ้อนไม่สามารถมีสิ่งที่ซ้ำซ้อนอยู่ในตัวมันเองได้"

, "at"
: "ณ"

, "never"
: "ไม่เลย"

, "after {0} occurrences"
: "หลังจากเกิดขึ้น {0} ครั้ง"

, "Except"
: ""

, "during events in the calendars"
: ""

, "End"
: "สิ้นสุด"

, "Until has to be after event start"
: "จนถึง ต้องไปอยู่"

, "The event is longer than the recurring interval"
: ""

, "Every {0}. Day"
: "ทุกๆ {0} วัน"

, "Every {0}. Week at"
: "ทุกๆ {0} สัปดาห์ เมื่อ"

, "Every {0}. Month"
: "ทุกๆ {0} เดือน"

, "at the"
: "เมื่อ"

, "first"
: "ลำดับที่หนึ่ง"

, "second"
: "ลำดับที่สอง"

, "third"
: "ลำดับที่สาม"

, "fourth"
: "ลำดับที่สี่"

, "last"
: "ลำดับสุดท้าย"

, "Every {0}. Year"
: "ทุกๆ {0} ปี"

, "of"
: "ของ"

, "Summary"
: "ข้อสรุป"

, "Organizer"
: "ผู้นัดหมาย"

, "Description"
: "การอธิบาย"

, "Location"
: "สถานที่"

, "Start Time"
: "เวลาที่เริ่ม"

, "End Time"
: "เวลาที่สิ้นสุด"

, "Attendee"
: "ผู้เข้าร่วม"

, "whole day"
: "ทั้งวัน"

, "Week {0} :"
: "สัปดาห์ที่ {0}"

, "Poll, Polls"
: [
  ""

]
, "Options"
: ""

, "Alternative Dates"
: ""

, "Set as definite event"
: ""

, "Create Poll for this Event"
: ""

, "Name for poll"
: ""

, "Create scheduling suggestions and pick the best alternative based on user feedback."
: ""

, "Share the link below to poll for attendee status feedback."
: ""

, "Public URL"
: ""

, "Protect poll with a password"
: ""

, "Only invited attendee can reply"
: ""

, "Start Date"
: ""

, "Info"
: ""

, "loading alternative dates"
: ""

, "Select one Event Only"
: ""

, "You need to select exactly one event as the definite event."
: ""

, "Setting definite event"
: ""

, "New Event"
: "เหตุการณ์ใหม่"

, "Calendar, Calendars"
: [
  "ปฏิทิน"

]
, "Event not found"
: ""

, "The Event was deleted in the meantime or you don't have access rights to it."
: ""

, "Switch to public poll"
: ""

, "Welcome {name}"
: ""

, "This is a closed poll. No Attendee can be added."
: ""

, "This poll is closed already"
: ""

, "I am not {name}"
: ""

, "Login"
: ""

, "{headerDate, date, full} {headerDate, time, short}"
: ""

, "Cancel"
: ""

, "Save"
: ""

, "By using this service you agree to our terms and conditions"
: ""

, "Use your personal link please."
: ""

, "We have sent it to your E-Mail account again."
: ""

, "If you did not receive the link, please contact the organiser."
: ""

, "Password"
: ""

, "Submit"
: ""

, "Wrong password!"
: ""

, "Please log in"
: ""

, "User name"
: ""

, "Calendar of {name}"
: ""

, "An unexpected error occurred."
: ""

, "Add attendee"
: "เพิ่มผู้เข้าร่วม"

, "Sort Attendee"
: "แยกประเภทผู้เข้าร่วม"

, "Check to filter for this attendee"
: "ทำสัญลักษณ์เพื่อกรองให้ผู้เข้าร่วมคนนี้"

, "Unavailable"
: ""

, "Loading events, please wait..."
: "กำลังโหลดเหตุการณ์ กรุณารอสักครู่"

, "Cut event"
: ""

, "Copy Event to clipboard"
: ""

, "Stop cut / copy & paste"
: ""

, "Print Page"
: "พิมพ์หน้า"

, "Loose-Leaf"
: ""

, "Sheet"
: "แผ่น"

, "Grid"
: "ขอบ"

, "Timeline"
: ""

, "Day"
: "วัน"

, "Week"
: "สัปดาห์"

, "Month"
: "เดือน"

, "Year"
: ""

, "Custom Selection"
: ""

, "Import Events"
: "นำเข้า เหตุการณ์"

, "Paste event \"{0}\""
: "วาง เหตุการณ์ \"{0}\""

, "Set my response"
: "ตั้งค่าการตอบสนองของฉัน"

, "Copy {0}"
: "คัดลอก {0}"

, "Set event status"
: ""

, "Updating event in the past"
: "ปรับปรุงเหตุการณ์ที่ผ่านมา"

, "Update this event"
: "ปรับปรุงเหตุการณ์นี้"

, "Do not update this event"
: "ไม่ต้องปรังปรุงเหตุการณ์นี้"

, "Creating event in the past"
: "กำลังสร้างเหตุการณ์ที่ผ่านมา"

, "Create this event"
: "สร้างเหตุการณ์นี้"

, "Do not create this event"
: "ไม่ต้องสร้างเหตุการณ์นี้"

, "Update this event only"
: "ปรับปรุงเหตุการณ์นี้เท่านั้น"

, "Update this and all future events"
: "ปรับปรุงเหตุการณ์นี้และทุก ๆ เหตุการณ์ในอนาคต"

, "Update whole series"
: "ปรับปรุงทุกชุดทั้งหมด"

, "Update nothing"
: "ไม่ได้ปรับปรุงใด ๆ"

, "Update Event"
: "ปรับปรุงเหตุการณ์"

, "Please Change Selection"
: "กรุณาเปลี่ยนที่ทำการเลือกไว้"

, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
: "สิ่งที่คุณเลือกมีเหตุการณ์ที่ซ้ำซ้อนกันอยู่ เหตุการณ์ที่ซ้ำซ้อนกันจะต้องลบออกทีละรายการ\n "

, "Delete Event"
: "ลบเหตุการณ์"

, "Delete this event only"
: "ลบเหตุการณ์นี้เท่านั้น"

, "Delete this and all future events"
: "ลบเหตุการณ์นี้และทุก ๆ เหตุการณ์ในอนาคต"

, "Delete whole series"
: "ลบหมดทุกชุด"

, "Delete nothing"
: "ไม่ได้ลบสิ่งใด"

, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
: [
  "คุณแน่ใจว่าคุณต้องการลบ {0} เหตุการณ์ที่เลือก?"

]
, "Could not Print"
: "ไม่สามารถพิมพ์ออกได้"

, "Sorry, your current view does not support printing."
: "ขอโทษที่การดู ณ ปัจจุบันของคุณไม่สนับสนุนการพิมพ์"

, "Scheduling Conflict"
: "จัดแจงข้อขัดแย้ง"

, "The following attendee are busy at the requested time:"
: "ผู้เข้าร่วมรายต่อไปนี้ไม่ว่าง ณ เวลาที่กำหนด"

, "Ignore Conflict"
: "เพิกเฉยข้อขัดแย้ง"

, "Edit Event"
: "จัดการเหตุการณ์"

, "Cancel this action"
: "ยกเลิกการกระทำนี้"

, "Update Status for all Attendee?"
: ""

, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
: ""

, "Manage Resources"
: "จัดการ แหล่งที่มา"

, "GENDER_Attendee"
: ""

, "Select Attendee"
: "เลือก ผู้เข้าร่วม"

, "Attachments"
: ""

, "Private"
: "ส่วนตัว"

, "Tags"
: "ป้ายกำกับ"

, "Blocking"
: "การจัดกลุ่มระเบียน"

, "Tentative"
: "เบื้องต้น"

, "Import Definition Success!"
: "นำเข้าคำจำกัดความ ประสบความสำเร็จ!"

, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
: ""

, "Choose Import File"
: "เลือก ไฟล์นำเข้า"

, "Please choose the file that contains the records you want to add to Tine 2.0"
: "กรุณาเลือกไฟล์ที่มีบันทึกที่คุณต้องการจะเพิ่มใน Tine 2.0"

, "Select file containing your {0}"
: "เลือกไฟล์ที่มี {0} ของคุณ"

, "once"
: "ครั้งเดียว"

, "hourly"
: "ทุกชั่วโมง"

, "daily"
: "ทุกวัน"

, "weekly"
: "ทุกสัปดาห์"

, "Choose Remote Location"
: "เลือกที่ตั้งที่ห่างไกล"

, "Please choose a remote location you want to add to Tine 2.0"
: "กรุณาเลือกสถานที่ที่ห่างไกลที่คุณต้องการจะเพิ่มใน Tine 2.0"

, "Username"
: ""

, "Refresh time"
: ""

, "General Settings"
: "ค่าติดตั้งทั่วไป"

, "Calendar name (you need permissions to add events)"
: ""

, "What should the file you upload look like?"
: ""

, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
: ""

, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
: ""

, "Please select the import format of the file you want to upload"
: ""

, "Download example file"
: ""

, "Remote / ICS"
: ""

, "Remote / CalDAV (BETA)"
: ""

, "Upload"
: ""

, "Choose File and Format"
: ""

, "Select type of source"
: "เลือก ประเภทของแหล่งข้อมูล"

, "Please select the type of source you want to add to Tine 2.0"
: "กรุณาเลือกประเภทของแหล่งข้อมูลที่คุณต้องการจะเพิ่มไปยัง Tine 2.0"

, "Importing {0}"
: ""

, "Back"
: ""

, "Next"
: ""

, "Ok"
: ""

, "Free Time Search"
: ""

, "Searching for Free Time..."
: ""

, "No Free Time found"
: ""

, "No free timeslot could be found Until {0}. Do you want to continue?"
: ""

, "Continue"
: ""

, "Give up"
: ""

, "Free Time Search Options"
: ""

, "private classification"
: "การแยกประเภทส่วนบุคคล"

, "recurring event"
: "เหตุการณ์ซ้ำซ้อน"

, "recurring event exception"
: "ข้อยกเว้นเมื่อเหตุการณ์ซ้ำซ้อน"

, "has alarm"
: "มีการแจ้งเตือน"

, "has attachments"
: "มีสิ่งที่แนบมาด้วย"

, "is part of an open poll"
: ""

, "Mini Calendar"
: "ปฏิทินย่อ"

, "WK"
: "สัปดาห์"

, "{0} more..."
: "เพิ่มขึ้น {0}"

, "Resource Grant, Resource Grants"
: [
  ""

]
, "Invite Resource"
: ""

, "The grant to invite the resource to an event"
: ""

, "Read Resource"
: ""

, "The grant to read the resource itself"
: ""

, "Edit Resource"
: ""

, "The grant to edit the resource itself"
: ""

, "Export Resource"
: ""

, "The grant to export the resource itself"
: ""

, "Sync Resource"
: ""

, "The grant to synchronise the resource itself"
: ""

, "Resource Admin"
: ""

, "The grant to administrate the resource itself"
: ""

, "Add Events"
: ""

, "The grant to directly add events into this resource calendar"
: ""

, "Read Events"
: ""

, "The grant to read events from this resource calendar"
: ""

, "Export Events"
: ""

, "The grant to export events from this resource calendar"
: ""

, "Sync Events"
: ""

, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
: ""

, "Events Free Busy"
: ""

, "The grant to get free/busy information of events from this resource calendar"
: ""

, "Edit Events"
: ""

, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
: ""

, "Delete Events"
: ""

, "The grant to delete events directly stored in this resource calendar"
: ""

, "Free Busy"
: ""

, "The grant to get free/busy information of events in this calendar"
: ""

, "The grant to access events marked as private in this calendar"
: ""

, "Rrule"
: ""

, "Please choose the Event to add the contacts to"
: "กรุณาเลือกเหตุการณ์เพื่อเพิ่มการติดต่อ"

, "Role"
: "หน้าที่"

, "Select Role"
: "เลือก หน้าที่"

, "Status"
: "สถานะ"

, "Select Status"
: "เลือก สถานะ"

, "Adding {0} Attendee to event"
: "กำลังเพิ่มผู้เข้าร่วม {0} คนในเหตุการณ์นี้"

, "no events found"
: "ไม่พบเหตุการณ์"

, "Searching..."
: "กำลังค้นหา"

, "Search Event"
: "ค้นหาเหตุการณ์"

, "Event, Events"
: [
  "เหตุการณ์"

]
, "Additional Tags ..."
: ""

, "non-blocking"
: "ไม่ได้บล็อค"

, "Displayed in"
: "ได้แสดงใน"

, "No Information"
: "ไม่มีข้อมูล"

, "Event Location"
: ""

, "From"
: ""

, "until"
: ""

, "Events"
: "เหตุการณ์"

, "Calendars"
: "ปฏิทิน"

, "Quick Search"
: "ค้นหาอย่างรวดเร็ว"

, "GENDER_Calendar"
: ""

, "Attendee Status"
: "สถานะผู้เข้าร่วม"

, "GENDER_Attendee Status"
: ""

, "Attendee Role"
: "หน้าที่ผู้เข้าร่วม"

, "GENDER_Attendee Role"
: ""

, "GENDER_Status"
: ""

, "GENDER_Blocking"
: ""

, "Classification"
: "การแยกประเภท"

, "GENDER_Classification"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Unknown date"
: "ไม่ระบุวัน"

, "{0} {1} o'clock"
: "{0} {1} นาฬิกา"

, "Event (as attendee)"
: "เหตุการณ์ (ในฐานะ ผู้เข้าร่วม)"

, "Event (as organizer)"
: "เหตุการณ์ (ในฐานะ ผู้นัดหมาย)"

, "Event attendee"
: "ผู้เข้าร่วมเหตุการณ์"

, "Attender, Attendee"
: [
  "ผู้เข้าร่วม"

]
, "Resource, Resources"
: [
  "แหล่งที่มา"

]
, "Resources"
: "แหล่งที่มา"

, "Anyone"
: ""

, "Name"
: "ชื่อ"

, "Calendar Hierarchy/Name"
: ""

, "Email"
: "อีเมล"

, "Maximum number of attendee"
: ""

, "Type"
: "ประเภท"

, "Default attendee status"
: ""

, "Busy Type"
: ""

, "Event finder options"
: ""

, "Click here to invite another attender..."
: "คลิ๊กที่นี่เพื่อเชิญผู้เข้าร่วมท่านอื่น..."

, "User"
: "ผู้ใช้"

, "Group"
: "กลุ่ม"

, "Member of group"
: "สมาชิกของกลุ่ม"

, "This is the calendar where the attender has saved this event in"
: "นี่เป็นปฏิทินที่ผู้เข้าร่วมจัดเก็บเหตุการณ์นี้ไว้"

, "Click icon to change"
: "กดที่เครื่องหมายเพื่อเปลี่ยน"

, "Availability of Attendee"
: ""

, "Whole Group or each Member of Group"
: ""

, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
: ""

, "Member of Group"
: ""

, "Loading Groupmembers..."
: ""

, "Remove Attender"
: "เอาผู้เข้าร่วมออก"

, "Compose email"
: "เขียนอีเมล"

, "Poll URL: {0}"
: ""

, "View Resource"
: ""

, "(as a group member)"
: "(ในฐานะสมาชิกกลุ่ม)"

, "External Attendee"
: "ผู้เข้าร่วมจากภายนอก"

, "Originally"
: "โดยเริ่มแรก"

, "Checking Calendar Data..."
: "กำลังตรวจสอบข้อมูลปฏิทิน"

, "Reply to Recurring Event"
: "ตอบสนองต่อเหตุการณ์ซ้ำซ้อน"

, "You are responding to an recurring event. What would you like to do?"
: "คุณกำลังตอบสนองต่อเหตุการณ์ที่ซ้ำซ้อน คุณจะทำอะไร?"

, "Respond to whole series"
: "ตอบสนองต่อทุกชุด"

, "Do not respond"
: "ไม่ตอบสนอง"

, "The event of this message does not exist"
: "เหตุการณ์ในข้อความนี้ไม่มีอยู่"

, "The sender is not authorised to update the event"
: "ผู้ส่งไม่ได้รับอนุญาตให้ปรับปรุงเหตุการณ์"

, "This message is already processed"
: "ข้อความนี้ได้ถูกดำเนินการแล้ว"

, "You are not an attendee of this event"
: "คุณไม่ได้เป็นผุ้เข้าร่วมในเหตุการณ์นี้"

, "This event has been deleted by the organizer"
: ""

, "This event has been canceled."
: ""

, "Unsupported message"
: "ข้อความที่ไม่ได้รับการสนับสนุน"

, "This is an event invitation for someone else."
: "นี่เป็นการเชิญให้ร่วมเหตุการณ์สำหรับผู้อื่น"

, "You have already replied to this event invitation."
: "คุณได้ตอบกลับไปยังคำเชิญเข้าร่วมเหตุการณ์นี้แล้ว"

, "The event got rescheduled. Set your response to:"
: ""

, "You received an event invitation. Set your response to:"
: "คุณได้รับคำเชิญเข้าร่วมเหตุการณ์ ตั้งค่าการตอบรับไปยัง:"

, "An invited attendee responded to the invitation."
: "ผุ้เข้าร่วมที่ได้รับเชิญได้ตอบกลับเรื่องคำเชิญแล้ว"

, "Unsupported method"
: "วิธีการที่ไม่สนับสนุน"

, "Suppress notification"
: ""

, "Color"
: ""

, "Enter description..."
: "ใส่ คำอธิบาย"

, "Grants"
: "อนุญาต"

, "This event is originally stored in a calendar you don't have access to."
: "เหตุการณ์นี้ได้รับการบันทึกแรกเริ่มในปฏิทินที่คุณไม่สามารถเข้าไปดูได้"

, "This event is originally stored in {0}"
: "เหตุการณ์นี้ได้รับการบันทึกแรกเริ่มใน {0}"

, "This event is additionally displayed in your personal calendar {0}"
: "เหตุการณ์นี้จะเพิ่มเข้าไปอัตโนมัติในปฏิทิน {0} ส่วนตัวของคุณ"

, "Colors"
: ""

, "Side bar color"
: ""

, "Color by Calendar"
: ""

, "Color by Attendee Calendar"
: ""

, "Color by Tags"
: ""

, "Color by Attendee Role"
: ""

, "Colors by response"
: ""

, "Colors by tags"
: ""

, "Colors by attendee"
: ""

, "Colors by resource"
: ""

, "View"
: "ดู"

, "Saved in"
: "ได้บันทึกใน"

, "Enter description"
: "ใส่ คำอธิบาย"

, "Notifications are disabled"
: ""

, "Notifications are enabled"
: ""

, "Print Event"
: ""

, "Send Notification?"
: ""

, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "End date is not valid"
: "วันที่สิ้นสุดไม่ถูกต้อง"

, "End date must be after start date"
: "วันที่สิ้นสุดต้องตามหลังวันที่เริ่มต้น"

, "End time is not allowed to be after the configured time."
: ""

, "Start date is not valid"
: "วันที่เริ่มต้นไม่ถูกต้อง"

, "Start date is not allowed to be before the configured time."
: ""

, "The summary must not be longer than 255 characters."
: "ข้อสรุปต้องไม่มากไปกว่า 255 ตัวอักษร"

, "The summary must have at least 1 character."
: "ข้อสรุปต้องมีอย่างน้อยที่สุด 1 ตัวอักษร"

, "Summary too Long"
: "ข้อสรุปยาวเกินไป"

, "Summary too Short"
: "ข้อสรุปสั้นเกินไป"

, "Set This Date as Definite Event?"
: ""

, "Do you want to close the poll and remove all other alternatives?"
: ""

, "Attendee/Resources"
: ""

, "Additional Attendees ..."
: ""

, "Default Status"
: ""

, "No Access"
: ""

, "All my events"
: "เหตุการณ์ทั้งหมดของฉัน"

, "Position on the left time axis, day and week view should start with"
: "เนื่องด้วยตำแหน่งบนเส้นเวลาที่เหลือ การดูแบบวันและแบบสัปดาห์ควรเริ่มต้นด้วย"

, "Position on the left time axis, day and week view should end with"
: ""

, "Default Start Time"
: ""

, "Scroll position on the left time axis, day and week view should start with"
: ""

, "Visible Time"
: ""

, "Time to be displayed at once"
: ""

, "Default Calendar"
: "ปฏิทินหลัก"

, "The default calendar for invitations and new events"
: "ปฏิทินหลักสำหรับคำเชิญและเหตุการณ์ใหม่"

, "Default Favorite"
: "ค่าที่ชอบหลัก"

, "The default favorite which is loaded on calendar startup"
: "ค่าที่ชอบหลักจะโหลดทันทีเมื่อเริ่มเปิดปฏิทิน"

, "Get Notification Emails"
: "ได้อีเมลแจ้งเตือน"

, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
: "ระดับของการกระทำที่คุณต้องการรับทราบ พึงระลึกว่าผู้ทำการนัดหมายจะได้รับการแจ้งเตือนเกี่ยวกับทุก ๆ อัพเดท รวมถึงทุก ๆ คำตอบของผู้เข้า นอกเสียจากว่าจะมีตั้งค่าเป็น \"ไม่เลย\""

, "Send Notifications Emails of own Actions"
: "ส่งอีเมลแจ้งเตือนของการกระทำของตัวเอง"

, "Get notifications emails for actions you did yourself"
: "ได้อีเมลแจ้งเตือนสำหรับสิ่งที่คุณได้ทำด้วยตัวคุณเอง"

, "Send Notifications Emails of tentative events"
: ""

, "Get notifications emails of tentative events"
: ""

, "Send Alarm Notifications Emails"
: ""

, "Get event alarms via email"
: ""

, "Enable Standard Alarm"
: "ตั้งการเตือนมาตรฐานได้"

, "New events get a standard alarm as defined below"
: "เหตุการณ์ใหม่ ๆ จะได้รับการเตือนที่ตั้งเป็นมาตรฐานได้ดังที่กำหนดไว้เบื้องล่างนี้"

, "Standard Alarm Time"
: "เวลาเตือนมาตรฐาน"

, "Minutes before the event starts"
: "จำนวนนาทีก่อนเหตุการณ์จะเริ่ม"

, "Default Attendee Strategy"
: ""

, "Default Attendee Strategy for new events"
: ""

, "Time Increment"
: ""

, "Increment of event time steps"
: ""

, "Default set Events to privat"
: ""

, "If enabled every created event is always privat"
: ""

, "First Day of Week"
: ""

, "On what day the week should be starting"
: ""

, "Default calendar strategy"
: ""

, "The calendar for new events if no container is selected"
: ""

, "Fixed Calendars"
: "ปฏิทินหลัก"

, "Calendars always selected regardless of all filter parameters."
: ""

, "Never"
: "ไม่เลย"

, "On invitation and cancellation only"
: "เฉพาะเรื่องคำเชิญและการยกเลิกเท่านั้น"

, "On time changes"
: "ตามการเปลี่ยนแปลงตามกำหนดการ"

, "On all updates but attendee responses"
: ""

, "On attendee responses too"
: "ตามที่ผู้เข้าร่วมตอบรับด้วย"

, "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
: ""

, "Crop Days"
: ""

, "Crop calendar view configured start and endtime."
: ""

, "Crop Days Limit Override"
: ""

, "Allow events outside start and endtime."
: ""

, "Week View Mouse Wheel Increment"
: ""

, "Default View for Events"
: ""

, "Event Status Available"
: ""

, "Possible event status. Please note that additional event status might impact other calendar systems on export or synchronisation."
: ""

, "Confirmed"
: ""

, "Canceled"
: ""

, "Event Classes Available"
: ""

, "Possible event classes. Please note that additional event classes might impact other calendar systems on export or synchronisation."
: ""

, "Public"
: ""

, "Confidential"
: ""

, "Event Transparencies Available"
: ""

, "Possible event transparencies. Please note that additional event transparencies might impact other calendar systems on export or synchronisation."
: ""

, "Transparent"
: ""

, "Opaque"
: ""

, "Attendee Status Available"
: "สถานะผู้เข้าร่วม ว่าง"

, "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
: ""

, "No response"
: "ไม่มีการตอบรับ"

, "Accepted"
: "ได้ยอมรับแล้ว"

, "Declined"
: "ได้ปฏิเสธแล้ว"

, "Attendee Roles Available"
: "หน้าที่ของผู้เข้าร่วม ว่าง"

, "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
: ""

, "Required"
: "ได้ต้องการ"

, "Optional"
: "ตามแต่จะเลือก"

, "Organizer has implicit edit grant"
: ""

, "Resource Types Available"
: ""

, "Possible resource types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Room"
: ""

, "Board"
: ""

, "Cable"
: ""

, "Car"
: ""

, "Coffee"
: ""

, "Homeoffice"
: ""

, "Lamp"
: ""

, "Laptop"
: ""

, "Material"
: ""

, "Projector"
: ""

, "Travel"
: ""

, "Free/Busy Types Available"
: ""

, "Possible free/busy types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Free"
: ""

, "Busy"
: ""

, "Filter timeslot for CalDAV events"
: "ตัวกรองช่วงเวลาสำหรับเหตุการณ์ CalDAV"

, "For how long in the past (in months) the events should be synchronized."
: "ระยะเวลานานแค่ไหนในอดีต (เป็นเดือน) ที่เหตุการณ์ควรจะได้รับการอัพเดท"

, "Filter timeslot for CalDAV events with SyncToken"
: ""

, "Timeslot for event notifications"
: ""

, "For how long in the past (in weeks) event notifications should be sent."
: ""

, "Default filter period (from) for events fetched via JSON API"
: ""

, "For how long in the past (in months) the events should be fetched."
: ""

, "Default filter period (until) for events fetched via JSON API"
: ""

, "For how long in the future (in months) the events should be fetched."
: ""

, "Disable iMIP for external organizers"
: ""

, "Disable notification for external organizers"
: ""

, "(CalDAV) Skip double events from personal or shared calendar"
: ""

, "(CalDAV) Skip double events from personal or shared calendar (\"personal\" > Skip events from personal calendar or \"shared\" > Skip events from shared calendar)"
: ""

, "Send notifications to every user with edit permissions of the added resources"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee"
: ""

, "Calendar Year View"
: ""

, "Adds year view to Calendar"
: ""

, "Calendar Extended Context Menu Actions"
: ""

, "Adds extended actions to event context menus"
: ""

, "Color Events By"
: ""

, "Choose event color by different criteria"
: ""

, "Recur Events Except"
: ""

, "Recur Events except on certain dates"
: ""

, "Activate Poll for Events"
: ""

, "Create alternative Events and let users as well as externals vote for the best option."
: ""

, "Lead Notification Confirmation"
: ""

, "Send Tentative Notifications"
: ""

, "Send notifications to event organiziers of events that are tentative certain days before event is due"
: ""

, "Enabled"
: ""

, "Days Before Due Date"
: ""

, "How many days before the events due date to start send notifications."
: ""

, "Additional Filter"
: ""

, "Additional filter to limit events notifications should be send for."
: ""

, "Mute Event Notifications for Polls"
: ""

, "Do not send invitations notifications for alternative events in an active poll."
: ""

, "GTCs for polls"
: ""

, "Freebusy Info"
: ""

, "What data the freebusy grant reveals"
: ""

, "only date & time"
: ""

, "and organizer"
: ""

, "and resources"
: ""

, "and calendar"
: ""

, "and other attendees"
: ""

, "Search Attenders Additional Filters"
: ""

, "User Additional Filters"
: ""

, "Group Additional Filters"
: ""

, "Resource Additional Filters"
: ""

, "Assign organizer meeting status on editGrant"
: ""

, "%s's personal calendar"
: "%s ของปฏิทินส่วนตัว"

, "Failed"
: ""

, "The right Resource Admin must be set once."
: ""

, "Different Calendar"
: ""

, "Exdate container move are not allowed"
: ""

, "Invalid URL given"
: "URL ที่ให้มาไม่ถูกต้อง"

, "The URL you used is invalid. Please use a valid one!"
: "URL ที่คุณใช้ไม่ถูกต้อง กรุณาใช้ที่ถูกต้อง!"

, "Calendars to export"
: ""

, "Export target"
: ""

, "VCalendar/ICS"
: ""

, "Export visible events to ics file"
: ""

, "Excel overview"
: ""

, "Word event sheet"
: ""

, "Export Events as Calendar Sheet"
: ""

, "VCalendar Report"
: ""

, "Export multiple calendars to ics files"
: ""

, "OpenDocument all data"
: ""

, "Export event data into ods spreadsheet"
: ""

, "Word details"
: ""

, "Excel all data"
: ""

, "Shared Calendar CSV"
: ""

, "Resource CSV"
: ""

, "You can not have more than one grants filter"
: ""

, "Import iCal-files"
: ""

, "unknown"
: "ไม่รู้จัก"

, "This contact has been automatically added by the system as an event attender"
: "ระบบได้เพิ่มการติดต่อนี้เข้าไปในเหตุการณ์ของผู้ร่วมอย่างอัตโนมัติ"

, "The email address has been shortened:"
: "ที่อยู่อีเมลได้ถูกย่อลง"

, "Every %s day"
: "ทุกๆ %s วัน"

, "Every %s week on"
: "ทุกๆ %s สัปดาห์ วัน"

, "Weekly on"
: "ทุกสัปดาห์ วัน"

, "and"
: "และ"

, "Every %1$s month on the %2$s %3$s"
: "ทุก ๆ %1$s เดือน วัน %2$s %3$s"

, "Monthly every %1$s %2$s"
: "รายเดือน ทุก ๆ %1$s %2$s"

, "Every %1$s month on the %2$s"
: "ทุก ๆ %1$s เดือน วัน %2$s"

, "Monthly on the %1$s"
: "ทุกเดือน วันที่ %1$s"

, "Yearly every %1$s %2$s of %3$s"
: "รายปี ทุก ๆ %1$s %2$s ของ %3$s"

, "Yearly on the %1$s of %2$s"
: "ทุกปี วันที่ %1$s ของ %2$s"

, "second to last"
: "ที่สองถึงสุดท้าย"

, "fifth"
: "ที่ห้า"

, "st"
: "ที่"

, "nd"
: "ที่"

, "rd"
: "ที่"

, "th"
: "ที่"

, "Start"
: "เริ่มต้น"

, "Priority"
: "ลำดับความสำคัญ"

, "Url"
: "Url"

, "Recurrance rule"
: "กฎเกี่ยวกับการซ้ำซ้อน"

, "Is all day event"
: "คือเหตุการณ์ทั้งวัน"

, "Organizer timezone"
: "โซนเวลาของผู้นัดหมาย"

, "Locked"
: ""

, "Closed"
: ""

, "Alarm for event \"%1$s\" at %2$s"
: "แจ้งเตือน เหตุการณ์ \"%1$s\" เมื่อ %2$s"

, "Event invitation \"%1$s\" at %2$s"
: "คำเชิญเข้าร่วมเหตุการณ์ \"%1$s\" เมื่อ %2$s"

, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
: ""

, "Event \"%1$s\" at %2$s has been canceled"
: "เหตุการณ์ \"%1$s\" เมื่อ %2$s ได้ถูกยกเลิก"

, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
: "เหตุการณ์ \"%1$s\" ได้เปลี่ยนจาก %2$s ไปเป็น %3$s"

, "Event \"%1$s\" at %2$s has been updated"
: "เหตุการณ์ \"%1$s\" เมื่อ %2$s ได้ถูกปรับปรุง"

, "%1$s accepted event \"%2$s\" at %3$s"
: "%1$s ได้ยอมรับเหตุการณ์ \"%2$s\" เมื่อ %3$s"

, "%1$s declined event \"%2$s\" at %3$s"
: "%1$s ได้ปฏิเสธเหตุการณ์ \"%2$s\" เมื่อ %3$s"

, "Tentative response from %1$s for event \"%2$s\" at %3$s"
: "การตอบรับที่ยังไม่แน่นอนจาก %1$s สำหรับเหตุการณ์ \"%2$s\" เมื่อ %3$s"

, "No response from %1$s for event \"%2$s\" at %3$s"
: "ไม่มีการตอบรับจาก %1$s สำหรับเหตุการณ์ \"%2$s\" เมื่อ %3$s"

, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
: ""

, "Attendee changes for event \"%1$s\" at %2$s"
: "มีการเปลี่ยนแปลงเกี่ยวกับผู้เข้าร่วมสำหรับเหตุการณ์ \"%1$s\" เมื่อ %2$s"

, "Tentative event notification for event \"%1$s\" at %2$s"
: ""

, "Unknown action"
: ""

, "Resource Management"
: ""

, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
: ""

, "Polls for recurring events are not supported"
: ""

, "This contact has been automatically added by the system as a poll attendee"
: ""

, "Attendance Confirmation for Poll \"%1$s\""
: ""

, "%1$s is scheduled for %2$s"
: ""

, "The poll \"%1$s\" has been closed."
: ""

, "The definite event is scheduled for \"%1$s\""
: ""

, "You can review the poll results here:"
: ""

, "Thank you for attendening the poll \"%1$s\""
: ""

, "To review or edit your status please use your personal link:"
: ""

, "Updates"
: "อัพเดท"

, "This is an event series exception."
: "นี่คือข้อยกเว้นหนึ่งของอนุกรมเหตุการณ์"

, "%1$s changed from \"%2$s\" to \"%3$s\""
: "%1$s ได้เปลี่ยนจาก \"%2$s\" เป็น \"%3$s\""

, "%1$s has been invited"
: "%1$s ได้รับเชิญ"

, "%1$s has been removed"
: "%1$s ได้เอาออก"

, "%1$s accepted invitation"
: "%1$s ได้ยอมรับคำเชิญ"

, "%1$s declined invitation"
: "%1$s ได้ปฏิเสธคำเชิญ"

, "Tentative response from %1$s"
: "การตอบรับที่ยังไม่แน่นอนจาก %1$s "

, "No response from %1$s"
: "ไม่มีการตอบรับจาก %1$s"

, "\"%2$s\" response from %1$s"
: "\"%2$s\" ตอบรับจาก %1$s"

, "Link"
: ""

, "Event details"
: "รายละเอียดของเหตุการณ์"

, "All events I attend"
: "ทุกเหตุการณ์ที่ฉันเข้าร่วม"

, "Awaiting response"
: "กำลังรอการตอบรับ"

, "Events I have not yet responded to"
: "เหตุการณ์ที่ฉันยังไม่ได้ตอบรับ"

, "Declined events"
: "เหตุการณ์ที่ได้ปฏิเสธไป"

, "Events I have declined"
: "เหตุการณ์ที่ฉันได้ปฏิเสธไป"

, "I'm organizer"
: "ฉันเป็นผู้นัดหมาย"

, "Events I'm the organizer of"
: "เหตุการณ์ที่ฉันเป็นผู้นัดหมาย"

, "manage shared calendars"
: "จัดการ ปฏิทินที่ใช้ร่วมกัน"

, "Create new shared calendars"
: "สร้าง ปฏิทินใหม่ที่ใช้ร่วมกัน"

, "manage shared calendars favorites"
: "จัดการ ปฏิทินโปรดที่ใช้ร่วมกัน"

, "Create or update shared calendars favorites"
: "สร้าง หรือ ปรับปรุง ปฏิทินที่ใช้ร่วมกัน"

, "manage resources"
: "จัดการ แหล่งที่มา"

, "All Rights to administrate resources"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "First name, ĺast name"
: ""

, "E-Mail address"
: ""

, "Please wait..."
: ""

, "General terms and conditions"
: ""

, "0009326B"
: ""

, "20"
: ""

, "00B359B9"
: ""

, "00997199"
: ""

, "Relation, Relations"
: [
  ""

]
, "Poll"
: ""

, "Calendar"
: "ปฏิทิน"

, "Do you really want to delete this event?"
: "คุณแน่ใจว่าคุณต้องการลบ {0} เหตุการณ์ที่เลือก?"

, "Resource Grant"
: ""

, "Event"
: "เหตุการณ์"

, "Attender"
: "ผู้เข้าร่วม"

, "Resource"
: "แหล่งที่มา"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
